@@ -9,6 +9,7 @@ from build123d import (
     BuildSketch,
     Box,
     Compound,
+    Cylinder,
     FilletPolyline,
     GridLocations,
     Line,
@@ -25,8 +26,6 @@ from build123d import (
     make_face,
 )
 
-from build123d.objects_part import Cylinder, Sphere
-
 # it's a bad habit, but I keep some simple test code under __main__
 # to make creating test object easy -- this adds ".fb_library" to the path
 if __name__ == "__main__":
